#
# spec file for package kf6-qqc2-desktop-style
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define qt6_version 6.7.0

%define rname qqc2-desktop-style
# Full KF6 version (e.g. 6.9.0)
%{!?_kf6_version: %global _kf6_version %{version}}
# Last major and minor KF6 version (e.g. 6.0)
%{!?_kf6_bugfix_version: %define _kf6_bugfix_version %(echo %{_kf6_version} | awk -F. '{print $1"."$2}')}
%bcond_without released
Name:           kf6-qqc2-desktop-style
Version:        6.10.0
Release:        1.1
Summary:        A Qt Quick Controls 2 Style for Desktop UIs
License:        GPL-2.0-or-later
URL:            https://www.kde.org
Source:         %{rname}-%{version}.tar.xz
%if %{with released}
Source1:        %{rname}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  kf6-extra-cmake-modules
BuildRequires:  cmake(KF6ColorScheme) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6Config) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6IconThemes) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6KirigamiPlatform) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6DBus) >= %{qt6_version}
BuildRequires:  cmake(Qt6Gui) >= %{qt6_version}
BuildRequires:  cmake(Qt6LinguistTools) >= %{qt6_version}
BuildRequires:  cmake(Qt6Quick) >= %{qt6_version}
BuildRequires:  cmake(Qt6QuickControls2) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
Requires:       kf6-sonnet-imports >= %{_kf6_bugfix_version}
%requires_eq    qt6-declarative-imports
# plasma6-workspace sets up the env variables so that this theme
# is picked by default. It still works fine without it (no requires),
# but looks better with it. By itself plasma6-workspace does not use
# it (yet), so only install it with qt6-declarative-imports.
Supplements:    (plasma6-workspace and qt6-declarative-imports)
Obsoletes:      qqc2-desktop-style-lang < %{version}

%description
A Qt Quick Controls 2 style engine that uses the desktop style
to draw controls with QStyle.

%package devel
Summary:        Development Files for Qt Quick Controls 2 Desktop Style
Requires:       kf6-qqc2-desktop-style >= %{version}

%description devel
This file contains cmake files to be used by projects that depend on
qqc2-desktop-style.
Usually not needed as it is only a runtime dependency.

%lang_package

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

%find_lang %{name} --all-name --with-qt

%files
%license LICENSES/*
%doc README.md
%dir %{_kf6_plugindir}/kf6/kirigami
%dir %{_kf6_plugindir}/kf6/kirigami/platform
%{_kf6_plugindir}/kf6/kirigami/platform/org.kde.desktop.so
%{_kf6_qmldir}/org/kde/desktop/
%{_kf6_qmldir}/org/kde/qqc2desktopstyle/

%files lang -f %{name}.lang

%files devel
%{_kf6_cmakedir}/KF6QQC2DesktopStyle/

%changelog
* Thu Jan  9 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.10.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.10.0
- Changes since 6.9.0:
  * Update dependency version to 6.10.0
  * Switch: Fix typo
  * updateItem when mnemonic active changes
  * Make use of animateClick in mnemonics
  * ToolButton: Remove unused id
  * Update version to 6.10.0
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.9.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.9.0
- Changes since 6.8.0:
  * Update dependency version to 6.9.0
  * org.kde.desktop: Add null contentItem checks to check/radio/switch controls
  * Use null contentItem instead of empty Item
  * Use Qt text rendering when high DPI scaling (kde#479891)
  * Bump KF and QT versions in ecm_set_disabled_deprecation_versions
  * Add a SwipeDelegate (kde#495291)
  * Don't include quiet packages in feature_summary
  * Update version to 6.9.0
* Mon Nov  4 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.8.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.8.0
- Changes since 6.7.0:
  * Update dependency version to 6.8.0
  * TextArea: Make placeholder wrap
  * Update version to 6.8.0
* Mon Oct  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.7.0
- Changes since 6.6.0:
  * Update dependency version to 6.7.0
  * kquickstyleitem: Don't crash if colors changed and style option is null
  * kirigamiintegration: Track changes to PlatformTheme where needed
  * TextFieldContextMenu: Open menu by keyPressed at TextField.cursorRectangle position
  * Update version to 6.7.0
* Sat Sep  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.6.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.6.0
- Changes since 6.5.0:
  * Update version to 6.6.0
  * Read Smallest font settings from the proper config (kde#490890)
* Mon Aug  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.5.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.5.0
- Changes since 6.4.0:
  * Update dependency version to 6.5.0
  * ScrollBar: Fix custom scrolling behavior (kde#488092)
  * Update version to 6.5.0
* Tue Jul  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.4.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.4.0
- Changes since 6.3.0:
  * combobox: Set focus on text field within combobox
  * Delegates: Use inset to control spacing around hover/selection highlight
  * Limit focus workaround to affected versions
  * itembranchindicators: Store QPersistentModelIndex instead of QModelIndex
  * itemindicators: Don't access thread-unsafe data from the render thread (kde#487850)
  * Implement baselineOffset for more controls
  * KQuickStyleItem: Mark baselineOffset method as const
  * Implement SplitView with splitter handles
  * support USE_DBUS option to enable/disable dbus use
* Wed Jun  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.3.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.3.0/
- Changes since 6.2.0:
  * Fix rendering the focus of our items (kde#486041)
  * Update background of Dialog
  * TreeViewDelegate: Replace top/bottom padding with vertical
  * TreeViewDelegate: Add return type annotations to methods
  * TreeViewDelegate: Make it actually vertically centered
  * Remove explicit maintainer from metainfo
  * TextArea, TextField: Fix position of a "selection end" cursor
  * TextField: Fix mobile cursor positioning for fields with custom padding
  * Context Menus: Port to pragma ComponentBehavior: Bound
  * Context Menus: Use controls directly instead of via QQC2
  * MobileTextActionsToolBar: Slightly refactor expressions
  * MobileTextActionsToolBar: Set text and display mode for action buttons
  * MobileTextActionsToolBar: Use symbolic versions of icons
  * ComboBox: Clip the ListView when its relevant
  * ComboBox: Use strict === equality operator
  * ComboBox: Replace magic numbers with standard named units
  * [TextArea] Access controlRoot directly
  * [TextArea] Enabled ComponentBehavior: Bound
  * [Combobox] Use Popup directly instead of via QQC2
  * DialogButtonBox: Use largeSpacing as padding
* Wed May 22 2024 Christophe Marin <christophe@krop.fr>
- Update qqc2-desktop-style-lang obsoleted version
* Mon May  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.2.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/6.2.0/
- Changes since 6.1.0:
  * DialogButtonBox: Use largeSpacing as padding
  * TreeViewDelegate: Fix non-observable modelIndex property getting stuck
  * [CheckIndicator] Use control as AbstractButton
  * Add missing dependency to private module
  * Add QTBUG to comment
  * Make SwitchIndicator more compiler-friendly
  * ItemBranchIndicators: Fix uninitialized member variable m_selected
  * StyleSingleton: Check whether object is qGuiApp
  * [RadioButton] Use id instead of parent lookup
  * [TabButton] Fix property type
  * Apply Kirigami.Units.cornerRadius to default list item background too
  * gitignore: add VS Code dir
  * Use consistent radius value from Kirigami.Units.radius
* Fri Apr  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.1.0
  * New feature release
- Changes since 6.0.0:
  * update version for new release
  * CheckIndicator: use Theme.View color, dont inherit parent
  * delegates: Unify alignment and horizontal stretching of labels
  * KQuickStyleItem: Replace manual loop with C++20 std::accumulate
  * Remove unneeded CMake stuff
  * Port away from deprecated ECMQMLModules
  * Add type annotations to functions
  * Qualify property lookups
  * Use local Label component directly
  * Use local property directly
  * Avoid looking up non-Item properties via Item-based properties
  * Avoid looking up non-Item properties via parent
  * Remove unused import statements
  * Declare dependencies on other QML modules
  * [ToolTip] Use local Label instead of importing QQC2
  * Completely disable animations when animations are globally disabled
  * Localization support
  * Add support for custom fonts in ToolButtons
  * autotests: test TextFieldContextMenu
  * Always use values from Kirigami.Theme as control palette (kde#479015)
* Wed Feb 21 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0
  * New bugfix release
  * Release announcement not available yet
- Changes since 5.249.0:
  * update version for new release
  * Set a small longPressThreshold to enable longPressed signal
  * Menu: Use StyleItem as a property
  * Menu: fix TextFieldContextMenu opening at wrong position (kde#481293)
  * MenuItem: remove some unused property bindings
  * DialogButtonBox: Respect QStyle::SH_DialogButtonBox_ButtonsHaveIcons
  * VerticalHeaderView: Don't highlight if selection doesn't match
  * HorizontalHeaderView: Fix incorrect highlighting when no selection model set
  * Revert "DefaultListItemBackground: use outline only to show focus"
  * Revert "Use consistent paddings for the first list item"
  * Use kirigami.theme.framecontrast
  * Specify QtQuick dependency for private plugin
  * Make sidebar drawer separators proper Separator
  * Set borders to follow same colors as Breeze widget style
  * update version for new release
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.249.0 (6.0 RC 2):
  * New bugfix release
  * For more details see https://kde.org/announcements/megarelease/6/rc2/
* Mon Jan 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.248.0 (6.0 RC 1)
  * For more details please see:
    https://kde.org/announcements/megarelease/6/rc1/
* Sat May 27 2023 Christophe Marin <christophe@krop.fr>
- Init kf6-qqc2-desktop-style
